from django import forms
from django.urls import reverse
from django.test import TestCase
from django.contrib import admin
from django.contrib.auth.models import User


from django_admin_hstore_widget.forms import HStoreFormField

from .models import Cat


class CatForm(forms.ModelForm):
    data = HStoreFormField()

    class Meta:
        model = Cat
        fields = ('name', 'data')


class CatAdmin(admin.ModelAdmin):
    form = CatForm


admin.site.register(Cat, CatAdmin)


class TestModel(TestCase):

    ADMIN_USERNAME = 'murphy'
    ADMIN_PASSWORD = 'cat'

    def _create_admin_user(self):
        admin = User.objects.create(
            username=self.ADMIN_USERNAME,
            is_staff=True,
            is_superuser=True,
            is_active=True
        )
        admin.set_password(self.ADMIN_PASSWORD)
        admin.save()

    def _login(self):
        self.client.login(username=self.ADMIN_USERNAME, password=self.ADMIN_PASSWORD)

    def test__hstore_field_edit_view__render(self):
        self._create_admin_user()
        self._login()

        cat = Cat.objects.create(name='Murphy', data={'race': '', 'gender': 'male'})
        url = reverse('admin:tests_cat_change', args=(cat.pk,))
        edit_view_response = self.client.get(url)

        self.assertEqual(edit_view_response.status_code, 200)

        # If the template is rendered with the django-admin-hstore-widget this class will be added to the textarea
        self.assertContains(edit_view_response, 'class="hstore-original-textarea"')

    def test__hstore_field_add_view__render(self):
        self._create_admin_user()
        self._login()

        url = reverse('admin:tests_cat_add')
        edit_view_response = self.client.get(url)

        self.assertEqual(edit_view_response.status_code, 200)
        # If the template is rendered with the django-admin-hstore-widget this class will be added to the textarea
        self.assertContains(edit_view_response, 'class="hstore-original-textarea"')



import os

import django


DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': 'django_hstore',
        'USER': '',
        'PASSWORD': '',
        'HOST': '',
        'PORT': ''
    },
}
INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.postgres',
    'django_admin_hstore_widget',

    'tests',
)

if django.VERSION[:2] >= (1, 7):
    INSTALLED_APPS = (
                         'django.contrib.admin.apps.AdminConfig',
                     ) + INSTALLED_APPS
else:
    INSTALLED_APPS = (
                         'django.contrib.admin',
                     ) + INSTALLED_APPS

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

SECRET_KEY = 'secret'

BASE_DIR = os.path.dirname(os.path.dirname(__file__))
DEBUG = True
LANGUAGE_CODE = 'en-us'
TIME_ZONE = 'UTC'
USE_I18N = True
USE_L10N = True
USE_TZ = True
STATIC_URL = '/static/'
ROOT_URLCONF = 'tests.urls'

ALLOWED_HOSTS = []

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]



from django import VERSION
from django.conf.urls import include
from django.contrib import admin

if VERSION[0] < 2:
    from django.conf.urls import url
    admin.autodiscover()
    urlpatterns = [
        url(r'^admin/', include(admin.site.urls)),
    ]
else:
    from django.urls import path
    urlpatterns = [
        path('admin/', admin.site.urls),
    ]
